#
# spec file for package longhornctl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           longhornctl
Version:        1.8.0
Release:        1.1
Summary:        CLI for the Longhorn cloud native distributed block storage
License:        Apache-2.0
URL:            https://github.com/longhorn/cli
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
longhornctl is a CLI (command-line interface) designed to simplify Longhorn
manual operations.

What Can You Do With longhornctl?

* Install and verify prelight requirements.
* Execute one-time Longhorn operations.
* Gain inside into your Longhorn system.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/longhorn/cli/meta.Version=v%{version} \
   -X github.com/longhorn/cli/meta.GitCommit=${COMMIT_HASH} \
   -X github.com/longhorn/cli/meta.BuildDate=${BUILD_DATE}" \
   -o bin/%{name} ./cmd/remote/

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%check
%{buildroot}/%{_bindir}/%{name} version | grep v%{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Wed Jan 22 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.8.0:
  * release: update version file for v1.8.0
  * fix(deps): update patch digest dependencies
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    ec79818
  * fix(deps): update module github.com/otiai10/copy to v1.14.1
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    5a6ca24
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    3f84afe
  * chore(deps): update docker/dockerfile docker tag to v1.12.1
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    5bad87d
  * fix(deps): update minor dependencies to v0.32.0
  * fix(deps): update k8s.io/utils digest to 24370be
  * fix(preflight): check the system default NFS version in mount
    config
  * feat(checker): check dmsetup package
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    e1932c6
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    6a06a48
  * fix(deps): update patch digest dependencies
  * fix(preflight): check package install by status flag
  * Update .coderabbit.yaml
  * fix(dep): not found transitive dependencies in go.mod
  * chore(deps): update docker/dockerfile docker tag to v1.12.0
  * feat(checker): add deployments to clusterrole
  * feat(checker): check Kube DNS has more than 2 replicas
  * chore: update vendor
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    d622157
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    b6fce15
  * fix(deps): update patch digest dependencies to v0.31.3
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    5685d80
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    614ae31
  * chore(deps): update patch digest dependencies
  * chore(deps): update docker/dockerfile docker tag to v1.11.1
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    43901cc
  * chore(deps): update docker/dockerfile docker tag to v1.11.0
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    deb5e95
  * fix(deps): update patch digest dependencies
  * fix(deps): update patch digest dependencies
  * chore(coderabbit): disable collapse and high_level_summary
  * fix(install/preflight): cos
  * fix(vendor): update sigs.k8s.io/kustomize/api to v0.18.0
  * fix(deps): update module sigs.k8s.io/kustomize/kyaml to v0.18.1
  * chore(dockerfile): update golangci-lint to v1.60.3
  * chore(deps): update docker dependencies
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    4c71f1c
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    a019530
  * docs: update docs
  * chore(build): support darwin platform
  * chore(vendor): update dependencies
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    797b589
  * fix(deps): update k8s.io/utils digest to 49e7df5
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    928beb3
  * fix(deps): update patch digest dependencies to v0.31.1
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    7060fef
  * fix(deps): update patch digest dependencies
  * fix(preflight): check and install the package `cryptsetup`
  * style(import): rename lhgo* alias to common*
  * fix(deps): update module github.com/longhorn/longhorn-manager
    to v1.7.0
  * fix(deps): update patch digest dependencies
  * fix(install): enable module `dm_crypt`
  * fix(check): check if module `dm_crypt` is enabled
  * fix(install): install packages before starting services
  * fix(deps): update module sigs.k8s.io/kustomize/kyaml to v0.17.2
  * fix(deps): update minor dependencies to v0.31.0
  * fix(ci): only set vx.y.z to latest release
  * fix(workflow): add missing tag for pull request action
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    b6ddc3e
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    f043d8c
  * fix(os): add `amazon linux` and `sle-micro` supports
  * fix(spdk): enable uio_pci_generic and vfio_pci kernel modules
  * chore(ci): add Conventional Commits GitHub Action
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    9e1e0e6
  * chore(docs): regenerate documents
  * feat(spdk): replace uio_pci_generic with vfio_pci
  * vendor: update dependencies
  * chore(readme): update "Prebuilt Binary"
  * fix(deps): update patch digest dependencies
  * chore: generate doc
  * feat(longhornctl): add example to help menu
  * fix(log): adjust log level to wait for DaemonSet container
  * chore(docs): update READMD.md
  * chore(docs): generate documents
  * feat(docs): add subcommand doc for generating documents
  * vendor: update dependencies
  * fix(command): duplicated other commands in help menu
  * build: down size binary
  * chore(image): rename image to longhorn-cli
  * fix(install): the check for spdk environment shoud be set to
    2048 MiB
  * fix(deps): update minor dependencies to v0.30.2
  * chore(deps): update docker/dockerfile docker tag to v1.9.0
  * fix(deps): update patch digest dependencies
  * fix(dockerfile): fix "/spdk not found" error
  * feat: add version subcommand
  * fix(dockerfile): fix missing spdk and longhornctl
  * chore(version): update version file to v1.8.0-dev
  * feat(ci): collect and release binaries and image
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.2:
  * release: update version file for v1.7.2
  * fix(install/preflight): cos
  * release: update version file for v1.7.2-rc2
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    4c71f1c
  * release: update version file for v1.7.2-rc1
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    a019530
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    3a320d8
  * fix(check): check if module `dm_crypt` is enabled
  * fix(install): enable module `dm_crypt`
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    797b589
  * fix(deps): update k8s.io/utils digest to 49e7df5
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    928beb3
  * fix(deps): update patch digest dependencies to v0.31.1
  * fix(deps): update github.com/longhorn/go-common-libs digest to
    7060fef
  * fix(deps): update module sigs.k8s.io/kustomize/kyaml to v0.17.2
  * fix(deps): update patch digest dependencies
* Wed Sep 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package longhornctl: CLI for the Longhorn cloud native
  distributed block storage
